diff --git a/pgadmin/frm/frmMain.cpp b/pgadmin/frm/frmMain.cpp
index dfc4263..093e6e3 100644
--- a/pgadmin/frm/frmMain.cpp
+++ b/pgadmin/frm/frmMain.cpp
@@ -536,6 +536,8 @@ void frmMain::Refresh(pgObject *data)
 {
 	bool done = false;
 	pgObject *obj = NULL;
+	// Flag, which need an event trigger refresh, if the refreshing object is type of PGM_SCHEMA.
+	static bool doNeedEvtTrgRefresh;
 
 	StartMsg(data->GetTranslatedMessage(REFRESHINGDETAILS));
 	browser->Freeze();
@@ -562,6 +564,21 @@ void frmMain::Refresh(pgObject *data)
 		data->SetDirty();
 
 		pgObject *newData = data->Refresh(browser, currentItem);
+	    if(newData->GetMetaType() == PGM_SCHEMA && !newData->IsCollection())
+            {
+                    doNeedEvtTrgRefresh = true;
+            }
+
+			// Event trigger's backend functions are at schema level.
+			// Hence, we can consider the Event Triggers are partially belongs to at schema level.
+			// So, if any schema got refreshed, we are refreshing the event trigger collection as like schema's object.
+			// It's a special case, which effects the schema operations on the event triggers as well.
+			//
+            if (doNeedEvtTrgRefresh)
+            {
+                    doNeedEvtTrgRefresh = false;
+                    Refresh(browser->GetObject(browser->GetNextSibling(browser->GetItemParent(browser->GetSelection()))));
+            }
 
 		done = !data->GetConnection() || data->GetConnection()->GetStatus() == PGCONN_OK;
 
diff --git a/pgadmin/schema/pgEventTrigger.cpp b/pgadmin/schema/pgEventTrigger.cpp
index e6bf808..ffe308b 100644
--- a/pgadmin/schema/pgEventTrigger.cpp
+++ b/pgadmin/schema/pgEventTrigger.cpp
@@ -122,10 +122,26 @@ void pgEventTrigger::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView
 			delete eventTriggerFunction;
 
 		wxString restr = wxT(" WHERE nsp.oid= ") + NumToStr(GetSchemaOid()) + wxT("::oid\n");
-		pgObject *evntTrgSchema;
-		evntTrgSchema = schemaFactory.CreateObjects((pgCollection *)browser->GetObject(browser->GetSelection()), 0, restr);
+		wxTreeItemId schemaCollNode = browser->GetPrevSibling(browser->GetItemParent(browser->GetSelection()));
+		wxTreeItemIdValue cookie;
+		wxTreeItemId schemaNode = browser->GetFirstChild(schemaCollNode, cookie);
+
+		// As we know, Event triggers are at database level, and it's backend functions are at schema level.
+		// Here, we are consolidating two different level objects in a single collection.
+		// Rather than creating a new schema(duplicate) object,
+		// We are traversing to it's schema nodes and collecting the proper schema object by identifying with it's OID.
+		//
+		while(browser->GetObject(schemaNode))
+		{
+			if (browser->GetObject(schemaNode)->GetOid() == GetSchemaOid())
+				break;
+			else
+				schemaNode = browser->GetNextChild(schemaCollNode, cookie);
+		}
+
 		// append function here
-		eventTriggerFunction = functionFactory.AppendFunctions(this, (pgSchema *)evntTrgSchema, browser, wxT(" WHERE pr.oid = ") + NumToStr(functionOid) + wxT("::oid\n"));
+		eventTriggerFunction = functionFactory.AppendFunctions(this, (pgSchema *)browser->GetObject(schemaNode), browser, wxT(" WHERE pr.oid = ") + NumToStr(functionOid) + wxT("::oid\n"));
+
 		if (eventTriggerFunction)
 		{
 			iSetFunction(eventTriggerFunction->GetQuotedFullIdentifier());
@@ -343,4 +359,4 @@ bool enabledisableEventTriggerFactory::CheckEnable(pgObject *obj)
 bool enabledisableEventTriggerFactory::CheckChecked(pgObject *obj)
 {
 	return obj && obj->IsCreatedBy(eventTriggerFactory) && ((pgEventTrigger *)obj)->GetEnabled();
-}
\ No newline at end of file
+}
